diff roundup/mailgw.py @ 2906:a8808157f892

fix some bugs introduced in refactoring of blobfiles filename() unless in debug mode, keep a single persistent connection through a single web or mailgw request fix enabling of DEBUG logging in db_test_case (no cmdline switch yet)
author Richard Jones <richard@users.sourceforge.net>
date Fri, 12 Nov 2004 04:07:05 +0000
parents 3ebbb8111503
children 98e6219ddb83
line wrap: on
line diff
--- a/roundup/mailgw.py	Thu Nov 11 21:36:07 2004 +0000
+++ b/roundup/mailgw.py	Fri Nov 12 04:07:05 2004 +0000
@@ -72,7 +72,7 @@
 an exception, the original message is bounced back to the sender with the
 explanatory message given in the exception.
 
-$Id: mailgw.py,v 1.157 2004-09-29 08:30:24 a1s Exp $
+$Id: mailgw.py,v 1.158 2004-11-12 04:07:03 richard Exp $
 """
 __docformat__ = 'restructuredtext'
 
@@ -801,10 +801,9 @@
         # committed before we reopen the database
         self.db.commit()
 
         # reopen the database as the author
         username = self.db.user.get(author, 'username')
-        self.db.close()
-        self.db = self.instance.open(username)
+        self.db.setCurrentUser(username)
 
         # re-get the class with the new database connection
         cl = self.db.getclass(classname)
@@ -801,10 +801,9 @@
         self.db.commit()
 
-        # reopen the database as the author
+        # set the database user as the author
         username = self.db.user.get(author, 'username')

Roundup Issue Tracker: http://roundup-tracker.org/